aboutsummaryrefslogtreecommitdiffstats
path: root/railties/test
diff options
context:
space:
mode:
authorGeorge Claghorn <george.claghorn@gmail.com>2019-01-04 23:09:12 -0500
committerGitHub <noreply@github.com>2019-01-04 23:09:12 -0500
commitdf8ee09ce71338cdf9816225df1bdebc707f3560 (patch)
tree5b2d265cdaca5c5859205389088b2bdc2327d935 /railties/test
parent88349cee3cb8f7bba662232fbc444eeebc8bb227 (diff)
parent0decd2ddc4a94cf522fc8ea8e6c73b9deedfdd93 (diff)
downloadrails-df8ee09ce71338cdf9816225df1bdebc707f3560.tar.gz
rails-df8ee09ce71338cdf9816225df1bdebc707f3560.tar.bz2
rails-df8ee09ce71338cdf9816225df1bdebc707f3560.zip
Merge pull request #34873 from georgeclaghorn/actiontext
Import Action Text
Diffstat (limited to 'railties/test')
-rw-r--r--railties/test/railties/engine_test.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/railties/test/railties/engine_test.rb b/railties/test/railties/engine_test.rb
index ca77c3a786..e62e8c8b44 100644
--- a/railties/test/railties/engine_test.rb
+++ b/railties/test/railties/engine_test.rb
@@ -90,8 +90,8 @@ module RailtiesTest
boot_rails
Dir.chdir(app_path) do
- # Install Active Storage and Action Mailbox migration files first so as not to affect test.
- `bundle exec rake active_storage:install action_mailbox:install`
+ # Install Active Storage, Action Mailbox, and Action Text migration files first so as not to affect test.
+ `bundle exec rake active_storage:install action_mailbox:install action_text:install`
output = `bundle exec rake bukkits:install:migrations`
["CreateUsers", "AddLastNameToUsers", "CreateSessions"].each do |migration_name|
@@ -177,8 +177,8 @@ module RailtiesTest
boot_rails
Dir.chdir(app_path) do
- # Install Active Storage and Action Mailbox migrations first so as not to affect test.
- `bundle exec rake active_storage:install action_mailbox:install`
+ # Install Active Storage, Action Mailbox, and Action Text migrations first so as not to affect test.
+ `bundle exec rake active_storage:install action_mailbox:install action_text:install`
output = `bundle exec rake railties:install:migrations`.split("\n")
assert_match(/Copied migration \d+_create_users\.core_engine\.rb from core_engine/, output.first)